#!/bin/sh
#
# Galaxy 19 (97W) Transponder Analysis Helper Script
#
# This script makes it easy to analyze transponders from the 97W Galaxy 19 satellite
# by providing a menu of transponders discovered during blindscan.
#

SCRIPT_DIR="$(dirname "$(readlink -f "$0")")"

# Ensure the PID extractor is available
if [ ! -x "$(command -v pid_extractor_poc)" ] && [ ! -x "$SCRIPT_DIR/pid_extractor_poc" ]; then
    echo "Error: pid_extractor_poc tool not found."
    echo "Please make sure it's installed or compiled in the current directory."
    exit 1
fi

# Transponder data from blindscan results
echo "====================================================="
echo "Galaxy 19 (97W) Transponder Analysis Helper"
echo "====================================================="
echo ""
echo "Select a transponder to analyze:"
echo ""
echo "1) 4009000 kHz Vertical, SR: 15000000, System: DVB-S2, Modulation: APSK_16, FEC: 5/6"
echo "2) 4009000 kHz Horizontal, SR: 12887000, System: DVB-S2, Modulation: PSK_8, FEC: 5/6"
echo "3) 4019000 kHz Horizontal, SR: 3771000, System: DVB-S2, Modulation: PSK_8, FEC: 2/3"
echo "4) 4032000 kHz Horizontal, SR: 9603000, System: DVB-S2, Modulation: APSK_16, FEC: 5/6"
echo "5) 4064000 kHz Horizontal, SR: 4166000, System: DVB-S2, Modulation: APSK_16, FEC: 3/4"
echo "6) 4074000 kHz Horizontal, SR: 5416000, System: DVB-S2, Modulation: APSK_16, FEC: 2/3"
echo "7) 4119000 kHz Vertical, SR: 34285000, System: DVB-S2, Modulation: QAM_16, FEC: Auto"
echo "8) 4139000 kHz Horizontal, SR: 34284000, System: DVB-S2, Modulation: QAM_16, FEC: 5/6"
echo "9) Custom parameters"
echo ""
echo "0) Exit"
echo ""

read -p "Enter selection: " SELECTION

case $SELECTION in
    1)
        FREQ=4009000
        POLAR=1
        SYMRATE=15000000
        SYSTEM=1
        MOD=2
        FEC=4
        ;;
    2)
        FREQ=4009000
        POLAR=0
        SYMRATE=12887000
        SYSTEM=1
        MOD=1
        FEC=4
        ;;
    3)
        FREQ=4019000
        POLAR=0
        SYMRATE=3771000
        SYSTEM=1
        MOD=1
        FEC=2
        ;;
    4)
        FREQ=4032000
        POLAR=0
        SYMRATE=9603000
        SYSTEM=1
        MOD=2
        FEC=4
        ;;
    5)
        FREQ=4064000
        POLAR=0
        SYMRATE=4166000
        SYSTEM=1
        MOD=2
        FEC=3
        ;;
    6)
        FREQ=4074000
        POLAR=0
        SYMRATE=5416000
        SYSTEM=1
        MOD=2
        FEC=2
        ;;
    7)
        FREQ=4119000
        POLAR=1
        SYMRATE=34285000
        SYSTEM=1
        MOD=4
        FEC=0
        ;;
    8)
        FREQ=4139000
        POLAR=0
        SYMRATE=34284000
        SYSTEM=1
        MOD=4
        FEC=4
        ;;
    9)
        read -p "Enter frequency (kHz): " FREQ
        read -p "Enter polarity (0=H, 1=V): " POLAR
        read -p "Enter symbol rate: " SYMRATE
        read -p "Enter system (0=DVB-S, 1=DVB-S2): " SYSTEM
        read -p "Enter modulation (0=QPSK, 1=PSK8, 2=APSK16, 3=APSK32, 4=QAM16): " MOD
        read -p "Enter FEC (0=Auto, 1=1/2, 2=2/3, 3=3/4, 4=5/6, 5=7/8): " FEC
        ;;
    0)
        echo "Exiting."
        exit 0
        ;;
    *)
        echo "Invalid selection."
        exit 1
        ;;
esac

# Check if we should use the installed version or the local version
if [ -x "$(command -v pid_extractor_poc)" ]; then
    TOOL="pid_extractor_poc"
else
    TOOL="$SCRIPT_DIR/pid_extractor_poc"
fi

echo ""
echo "Starting analysis of transponder $FREQ kHz $([ "$POLAR" = "0" ] && echo "Horizontal" || echo "Vertical")"
echo ""

# Check if all optional parameters are defined
if [ -n "$SYMRATE" ] && [ -n "$SYSTEM" ] && [ -n "$MOD" ] && [ -n "$FEC" ]; then
    $TOOL $FREQ $POLAR 0 0 0 $SYMRATE $SYSTEM $MOD $FEC
else
    $TOOL $FREQ $POLAR 0 0 0
fi

echo ""
if [ $? -eq 0 ]; then
    echo "Analysis completed successfully."
else
    echo "Analysis failed. Please check your hardware and parameters."
fi